#!/bin/bash
#
# Federated Computer Proxy Service

PATH=$HOME/.docker/cli-plugins:/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin

config_proxy() {
  echo -ne "\n* Configuring fstack/proxy container.."
  spin &
  SPINPID=$!

  if [ ! -d "fstack/proxy" ]; then
    mkdir -p fstack/proxy/data/root/certs &> /dev/null
    cp fstack/dns/data/etc/letsencrypt/archive/$DOMAIN/fullchain1.pem fstack/proxy/data/root/certs/$DOMAIN.crt
    cp fstack/dns/data/etc/letsencrypt/archive/$DOMAIN/privkey1.pem fstack/proxy/data/root/certs/$DOMAIN.key
  fi

  DOMAIN_ARRAY=(${DOMAIN//./ })
  DOMAIN_FIRST=${DOMAIN_ARRAY[0]}
  DOMAIN_LAST=${DOMAIN_ARRAY[1]}

cat > fstack/proxy/docker-compose.yml <<EOF
version: '3.8'
services:
  proxy:
    image: jwilder/nginx-proxy
    container_name: proxy
    hostname: proxy.$DOMAIN
    domainname: $DOMAIN
    restart: always
    networks:
      fstack:
        ipv4_address: 172.99.0.16
    ports:
      - 80:80
      - 443:443
    volumes:
      - /var/run/docker.sock:/tmp/docker.sock:ro
      - ./data/root/certs:/etc/nginx/certs

networks:
  fstack:
    external: true
EOF
 
kill -9 $SPINPID &> /dev/null
echo -ne "done."
}

start_proxy() {
  # Start fstack/proxy with output to /dev/null
  echo -ne "\n* Starting fstack/proxy service.."
  spin &
  SPINPID=$!

  if [ $DEBUG ]; then
    # Start fstack/proxy with output to console for debug
    docker-compose -f fstack/proxy/docker-compose.yml -p proxy up
    [ $? -eq 0 ] && echo -ne "done.\n" || fail "There was a problem starting service fstack/proxy"
  else
    docker-compose -f fstack/proxy/docker-compose.yml -p proxy up -d &> /dev/null

    # Keep trying proxy port 443 to make sure it's up
    # before we proceed
    RETRY="23"
    while [ $RETRY -gt 0 ]; do
      nc -z 172.99.0.16 443 &> /dev/null
      if [ $? -eq 0 ]; then
        break
      else
        if [ "$RETRY" == 1 ]; then
          docker-compose -f fstack/proxy/docker-compose.yml -p proxy down &> /dev/null
          kill -9 $SPINPID &> /dev/null
          fail "There was a problem starting service fstack/proxy\nCheck the output of 'docker logs proxy' or turn on\ndebug with -d"
        fi
        ((RETRY--))
        sleep 7
      fi
    done
  fi

  kill -9 $SPINPID &> /dev/null
  echo -ne "done."
}
